==> jc-1.4.0.tar.gz: gnu/java/rmi/server/RMIVoidValue.h <==
// final class gnu.java.rmi.server.RMIVoidValue

// class file dependencies
// @dep_class 3ab8e9e24a11ba2a gnu_java_rmi_server_RMIVoidValue
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_RMIVoidValue_H_
#define _JC_gnu_java_rmi_server_RMIVoidValue_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_server_RMIVoidValue$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_refs	_jc_gnu_java_rmi_server_RMIVoidValue$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs	_jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$refs	_jc_gnu_java_rmi_server_RMIVoidValue$refs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$nonrefs	_jc_gnu_java_rmi_server_RMIVoidValue$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$object	_jc_gnu_java_rmi_server_RMIVoidValue$object;

typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$fields_struct	_jc_gnu_java_rmi_server_RMIVoidValue$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_RMIVoidValue$vmethods	_jc_gnu_java_rmi_server_RMIVoidValue$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIVoidValue$vtable	_jc_gnu_java_rmi_server_RMIVoidValue$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIVoidValue$vtype	_jc_gnu_java_rmi_server_RMIVoidValue$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_RMIVoidValue$fields_struct {
	struct _jc_gnu_java_rmi_server_RMIVoidValue$object	*INSTANCE;
};
extern _jc_gnu_java_rmi_server_RMIVoidValue$fields_struct _jc_gnu_java_rmi_server_RMIVoidValue$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIVoidValue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_RMIVoidValue$object *);

// Static methods
extern void _jc_gnu_java_rmi_server_RMIVoidValue$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIVoidValue$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIVoidValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_RMIVoidValue$vmethods	gnu_java_rmi_server_RMIVoidValue;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIVoidValue$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIVoidValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIVoidValue$refs {
    _jc_gnu_java_rmi_server_RMIVoidValue$sub_refs	gnu_java_rmi_server_RMIVoidValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIVoidValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs	gnu_java_rmi_server_RMIVoidValue;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIVoidValue$object {
	_jc_gnu_java_rmi_server_RMIVoidValue$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIVoidValue$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIVoidValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIVoidValue$vtype _jc_gnu_java_rmi_server_RMIVoidValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIVoidValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIVoidValue$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIVoidValue_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/RMIVoidValue.h <==
// final class gnu.java.rmi.server.RMIVoidValue

// class file dependencies
// @dep_class 3ab8e9e24a11ba2a gnu_java_rmi_server_RMIVoidValue
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_RMIVoidValue_H_
#define _JC_gnu_java_rmi_server_RMIVoidValue_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_server_RMIVoidValue$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_refs	_jc_gnu_java_rmi_server_RMIVoidValue$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs	_jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$refs	_jc_gnu_java_rmi_server_RMIVoidValue$refs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$nonrefs	_jc_gnu_java_rmi_server_RMIVoidValue$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$object	_jc_gnu_java_rmi_server_RMIVoidValue$object;

typedef struct _jc_gnu_java_rmi_server_RMIVoidValue$fields_struct	_jc_gnu_java_rmi_server_RMIVoidValue$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_RMIVoidValue$vmethods	_jc_gnu_java_rmi_server_RMIVoidValue$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIVoidValue$vtable	_jc_gnu_java_rmi_server_RMIVoidValue$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIVoidValue$vtype	_jc_gnu_java_rmi_server_RMIVoidValue$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_RMIVoidValue$fields_struct {
	struct _jc_gnu_java_rmi_server_RMIVoidValue$object	*INSTANCE;
};
extern _jc_gnu_java_rmi_server_RMIVoidValue$fields_struct _jc_gnu_java_rmi_server_RMIVoidValue$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIVoidValue$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_RMIVoidValue$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_rmi_server_RMIVoidValue$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIVoidValue$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIVoidValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_RMIVoidValue$vmethods	gnu_java_rmi_server_RMIVoidValue;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIVoidValue$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIVoidValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIVoidValue$refs {
    _jc_gnu_java_rmi_server_RMIVoidValue$sub_refs	gnu_java_rmi_server_RMIVoidValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIVoidValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_RMIVoidValue$sub_nonrefs	gnu_java_rmi_server_RMIVoidValue;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIVoidValue$object {
	_jc_gnu_java_rmi_server_RMIVoidValue$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIVoidValue$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIVoidValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIVoidValue$vtype _jc_gnu_java_rmi_server_RMIVoidValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIVoidValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIVoidValue$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIVoidValue_H_ */
